@@ -74,11 +74,6 @@ keyfile = {}
                     kf = config['default']['keyfile']
                 except:
                     kf = "unknown"
-#
-#
-# these error checks arent working
-#
-#
                 print(cs("ERROR:", "red"), cs("keyfile name must be .pem", "yellow"))
                 continue
             elif not os.path.isfile(kf):
@@ -96,14 +91,22 @@ keyfile = {}
             f.write(newconfig)
     return kf
 
+def check_tag_for_hint(hint, tag_value):
+    """return true if hint in tag value"""
+    if hint.lower() in tag_value.lower():
+        return True
+    return False
+
 def get_instance_info(instances, class_instance):
     """takes a list of instances"""
     """get and print instance info to the screen"""
     # collect info
     state_code = 0
     for instance in instances:
+        matching_hint = False
         instance_id = instance['Instances'][0]['InstanceId']
         image_id = instance['Instances'][0]['ImageId']
+        instance_key_name = instance['Instances'][0]['KeyName']
         class_instance.start_instance_id = instance_id
         class_instance.start_image_id = image_id
         state_code = instance['Instances'][0]['State']['Code']
@@ -115,6 +118,9 @@ def get_instance_info(instances, class_instance):
             instance_tags = ""
         tags_list = ""
         for instance_tag in instance_tags:
+            # call a function to check tags and hints
+            if check_tag_for_hint(class_instance.tag, instance_tag['Value']):
+                matching_hint = True
             tags_list += instance_tag['Key']+":"+instance_tag['Value']+", "
         tags_list = tags_list[:-2]
         if state_code == 16:
@@ -137,10 +143,20 @@ def get_instance_info(instances, class_instance):
         # output one instance's info
         if class_instance.pipe:
             description = description.replace(" - ", " ")
-            sys.stdout.write(description + '\n')
+
+            if class_instance.hint:
+                if matching_hint:
+                    sys.stdout.write(description + '\n')
+            else:
+                sys.stdout.write(description + '\n')
         else:
-            print(cs(state_name+"\n"+description+"\nTags: "+tags_list, state_color))
-            print("-------")
+            if class_instance.hint:
+                if matching_hint:
+                    print(cs(state_name+"\n"+description+"\nKey Name: "+instance_key_name+"\nTags: "+tags_list, state_color))
+                    print("-------")
+            else:
+                print(cs(state_name+"\n"+description+"\nKey Name: "+instance_key_name+"\nTags: "+tags_list, state_color))
+                print("-------")
 
 def stop_and_start(instances, class_instance):
     """stop and start instances"""
@@ -254,7 +270,7 @@ class ArgHandler:
 
     number_of_instances = 0    
 
-    def __init__(self, tag, key, region, green, red, host, yes, connect, pipe, dokey, leave):
+    def __init__(self, tag, key, region, green, red, host, yes, connect, pipe, dokey, leave, hint):
         self.tag = tag
         self.key = key
         self.region = region
@@ -266,6 +282,7 @@ class ArgHandler:
         self.pipe = pipe
         self.dokey = dokey
         self.leave = leave
+        self.hint = hint
         self.switch = False
         self.verbing = False
         self.verb = "continue"
@@ -328,7 +345,7 @@ class ArgHandler:
     def get_instances(self):
         """get instances"""
         # if there's no positional arg output info for all instances and do nothing
-        if self.tag == "none":
+        if self.tag == "none" or self.hint:
             cmd = "aws ec2 describe-instances {}--output json".format(self.selected_region)
             instances = subprocess.check_output(cmd, shell=True).decode("utf-8").strip()
             if not self.red and not self.green:
@@ -385,6 +402,7 @@ def main():
     parser.add_argument("-R", "--region", help="specify a different region", default=None)
     parser.add_argument('-g', '--green', action='store_true', help='start.')
     parser.add_argument('-r', '--red', action='store_true', help='stop.')
+    parser.add_argument('--hint', action='store_true', help='attempt to find instances with tag hint or partial tag.')
     parser.add_argument('-L', '--leave', action='store_true', help='do not change instance state.')
     parser.add_argument('-y', '--yes', action='store_true', help='automatically approve all y/n prompts.')
     parser.add_argument('-H', '--host', action='store_true', help='use hostnames instead of ip addresses.')
@@ -404,9 +422,10 @@ def main():
     pipe = args.pipe
     dokey = args.keyfile
     leave = args.leave
+    hint = args.hint
 
     # instantiate ArgHandler class
-    shell = ArgHandler(tag, key, region, green, red, host, yes, connect, pipe, dokey, leave)
+    shell = ArgHandler(tag, key, region, green, red, host, yes, connect, pipe, dokey, leave, hint)
 
     #initial error checking
     shell.error_check()
